mode.types.supervisors — mode-ng 0.4.0 documentation

# `mode.types.supervisors`

Type classes for `mode.supervisors`.

class mode.types.supervisors.SupervisorStrategyT(*services: ServiceT, max_restarts: Union[timedelta, int, float, str] = 100.0, over: Union[timedelta, int, float, str] = 1.0, raises: Optional[Type[BaseException]] = None, replacement: Optional[Callable[[ServiceT, int], Awaitable[ServiceT]]] = None, **kwargs: Any)

  Base type for all supervisor strategies.

  Diag: Type[DiagT]
  abstract add(*services: ServiceT) → None
  async_exit_stack: AsyncExitStack
  diag: DiagT
  abstract discard(*services: ServiceT) → None
  exit_stack: ExitStack
  max_restarts: float
  over: float
  raises: Type[BaseException]
  replacement: Optional[ReplacementT]
  abstract async restart_service(service: ServiceT) → None
  abstract service_operational(service: ServiceT) → bool
  shutdown_timeout: float
  abstract wakeup() → None